/*
 *	file.c
 *
 *  Copyright (C) 1997,1998 Hermann Samso
 */

#include <stdio.h>
#include <stdlib.h>
#include "file.h"
#include "delfin.h"

BOOL FileExists(CHAR* fname) {
	FILE* fp;

	if (trace_on)
		printf("FileExists(\"%s\")\n", fname);
	
	fp = fopen(fname, "r");
   	if (fp == NULL)
   		return FALSE;
   	fclose(fp);
         
    return TRUE;
}
            

ULONG FileSize(CHAR* fname) {
	FILE* fp;
	long tmp, tmp2;

	if (trace_on)
		printf("FileSize(\"%s\")\n", fname);
		
	fp = fopen(fname, "r");
	if (fp == NULL)
		return 0;
	
    tmp = ftell(fp);
    fseek(fp, 0, SEEK_END);
    tmp2 = ftell(fp);
    fseek(fp, tmp, SEEK_SET);
	fclose(fp);
    return(tmp2-tmp);
}


/* msize, to see size of allocated mem doesn't exist??!? */
/* Reads a whole file to memory */
UBYTE* FileReadAll(CHAR* fname) {
	ULONG length;

	if (trace_on)
		printf("FileReadAll(\"%s\")\n", fname);	
	
	length = FileSize(fname);
	return(FileRead(fname, 0, length));
}


/* Reads part of file to memory */
UBYTE* FileRead(CHAR* fname, ULONG start, ULONG length) {
	FILE* fp;
	UBYTE* mem;

	if (trace_on)
		printf("FileRead(\"%s\", %li, %li)\n", fname, start, length);
		
	/* open file */
	fp = fopen(fname, "r");
	if (fp == NULL)
		return NULL;

	/* set position indicator to start of file */
	if (fseek(fp, start, SEEK_SET) != 0) {
		fprintf(stderr, "FileRead: Error seeking start of file!\n");
		fclose(fp);
		return NULL;
	}

	/* allocate 'length' bytes */
	mem = (UBYTE*)malloc(length);
	if (mem == NULL) {
		fprintf(stderr, "FileRead: Error allocating mem!\n");
		fclose(fp);
		return NULL;
	}
	
	/* read bytes from file */
	fread(mem, 1, length, fp);

	fclose(fp);
		
	return ((UBYTE*)mem);
}


/* 
 * Appends buffer to file
 *
 */
void FileAppend(CHAR* fname, UBYTE* buffer, ULONG length) {
	FILE* fp;

	if (trace_on)
		printf("FileAppend(\"%s\", %p, %li)\n", fname, buffer, length);
		
	// open file
	fp = fopen(fname, "a");
	if (fp == NULL)
		return;
		
/* fseek supposedly positions stream at end of file
	// set position indicator to start of file
	if (fseek(fp, 0, SEEK_END) != 0) {
		fprintf(stderr, "FileAppend: Error seeking end of file!\n");
		fclose(fp);
		return;
	}
*/
	// read bytes from file
	fwrite(buffer, 1, length, fp);
	fclose(fp);
}

